# Generated by Django 2.0 on 2018-04-17 12:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('spectator_events', '0037_exhibition_to_museum'),
    ]

    operations = [
        migrations.AlterField(
            model_name='event',
            name='kind',
            field=models.CharField(choices=[('cinema', 'Cinema'), ('concert', 'Concert'), ('comedy', 'Comedy'), ('dance', 'Dance'), ('museum', 'Gallery/Museum'), ('gig', 'Gig'), ('theatre', 'Theatre'), ('misc', 'Other')], help_text='Used to categorise event. But any kind of Work can be added to any kind of Event.', max_length=20),
        ),
    ]



from django.conf import settings


# Creating all the defaults for settings.
# In our code, if we want to use a SPECTATOR_* setting we should import
# from here, not django.conf.settings.

GOOGLE_MAPS_API_KEY = getattr(settings, 'SPECTATOR_GOOGLE_MAPS_API_KEY', '')

# The characters to use for things that require an automatically-generated
# URL slug:
SLUG_ALPHABET = getattr(
    settings, 'SPECTATOR_SLUG_ALPHABET', 'abcdefghijkmnopqrstuvwxyz23456789')

# The salt value to use when generating URL slugs:
SLUG_SALT = getattr(settings, 'SPECTATOR_SLUG_SALT', 'Django Spectator')



from django.conf import settings


# e.g. "8 Apr 2018"
DATE_FORMAT = getattr(settings, 'SPECTATOR_READING_DATE_FORMAT', '%-d %b %Y')

# e.g. "2018"
DATE_YEAR_FORMAT = getattr(settings, 'SPECTATOR_READING_DATE_YEAR_FORMAT', '%Y')

# e.g. "Apr"
DATE_MONTH_FORMAT = getattr(settings, 'SPECTATOR_READING_DATE_YEAR_FORMAT', '%b')

# e.g. "8"
DATE_DAY_FORMAT = getattr(settings, 'SPECTATOR_READING_DATE_YEAR_FORMAT', '%-d')

# e.g. "Apr 2018"
DATE_YEAR_MONTH_FORMAT = getattr(settings, 'SPECTATOR_READING_DATE_YEAR_FORMAT', '%b %Y')

# e.g. "8 Apr"
DATE_MONTH_DAY_FORMAT = getattr(settings, 'SPECTATOR_READING_DATE_YEAR_FORMAT', '%-d %b')

# e.g. "2017–2018"
PERIOD_FORMAT_SHORT = getattr(settings, 'SPECTATOR_READING_PERIOD_FORMAT_SHORT', '{}–{}')

# e.g. "8 Apr to 2 May 2018"
PERIOD_FORMAT_LONG = getattr(settings, 'SPECTATOR_READING_PERIOD_FORMAT_LONG', '{} to {}')
